@@ -17,4 +17,4 @@ which gnome-autogen.sh || {
 	exit 1
 }
 
-USE_GNOME2_MACROS=1 . gnome-autogen.sh
+REQUIRED_AUTOMAKE_VERSION=1.6 USE_GNOME2_MACROS=1 . gnome-autogen.sh
