@@ -57,6 +57,11 @@ static gboolean apply_to_existing = FALSE;
  */
 static char **files = NULL;
 
+/**
+ * The main loop.
+ */
+GMainLoop *loop = NULL;
+
 /**
  * Evaluate a s-expression.
  */
@@ -99,7 +104,7 @@ int main(int argc, char **argv) {
     { G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &files, N_("Configuration files to use"), NULL },
     { NULL }
   };
-  GMainLoop *loop;
+
   GError *error = NULL;
   GOptionContext *context;
 
@@ -112,7 +117,7 @@ int main(int argc, char **argv) {
   gdk_init(&argc, &argv);
 
   /* Parse the arguments */
-  context = g_option_context_new ("- Devil's Pie");
+  context = g_option_context_new ("- Devil's Pie " VERSION);
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
   g_option_context_parse (context, &argc, &argv, &error);
 
