@@ -72,16 +72,19 @@ static const struct {
   { "stick", func_stick, FALSE },
   { "unstick", func_unstick, FALSE },
   { "set_workspace", func_set_workspace, FALSE },
+  { "change_workspace", func_change_workspace, FALSE },
   { "set_viewport", func_set_viewport, FALSE },
   { "skip_pager", func_skip_pager, FALSE },
   { "skip_tasklist", func_skip_tasklist, FALSE },
   { "above", func_above, FALSE },
   { "below", func_below, FALSE },
+  { "decorate", func_decorate, FALSE },
   { "undecorate", func_undecorate, FALSE },
   { "wintype", func_wintype, FALSE },
   { "opacity", func_opacity, FALSE },
   { "spawn_sync", func_spawn_sync, FALSE },
   { "spawn_async", func_spawn_async, FALSE },
+  { "quit", func_quit, FALSE},
 };
 
 /**
